pub struct ReadOnly<R>(pub R);Expand description
An adaptor which implements Splittable for any AsyncRead, with the
write half being ().
This can be used to create a framed stream with only a reader, using
the AsyncReadExt::framed or AsyncReadExt::bytes method.
Tuple Fields
0: RTrait Implementations
Sourceimpl<R: AsyncRead> AsyncRead for ReadOnly<R>
impl<R: AsyncRead> AsyncRead for ReadOnly<R>
Sourceimpl<R> Splittable for ReadOnly<R>
impl<R> Splittable for ReadOnly<R>
Sourcetype ReadHalf = R
type ReadHalf = R
The type of the read half, which normally implements
AsyncRead or
AsyncReadAt.Sourcetype WriteHalf = ()
type WriteHalf = ()
The type of the write half, which normally implements
AsyncWrite or
AsyncWriteAt.Auto Trait Implementations
impl<R> Freeze for ReadOnly<R>where
R: Freeze,
impl<R> RefUnwindSafe for ReadOnly<R>where
R: RefUnwindSafe,
impl<R> Send for ReadOnly<R>where
R: Send,
impl<R> Sync for ReadOnly<R>where
R: Sync,
impl<R> Unpin for ReadOnly<R>where
R: Unpin,
impl<R> UnsafeUnpin for ReadOnly<R>where
R: UnsafeUnpin,
impl<R> UnwindSafe for ReadOnly<R>where
R: UnwindSafe,