pub struct WriteOnly<W>(pub W);Expand description
An adaptor which implements Splittable for any AsyncWrite, with the
read half being ().
This can be used to create a framed sink with only a writer, using
the AsyncWriteExt::framed or AsyncWriteExt::bytes method.
Tuple Fields
0: WTrait Implementations
Sourceimpl<W: AsyncWrite> AsyncWrite for WriteOnly<W>
impl<W: AsyncWrite> AsyncWrite for WriteOnly<W>
Sourceasync fn flush(&mut self) -> Result<()>
async fn flush(&mut self) -> Result<()>
Attempts to flush the object, ensuring that any buffered data reach
their destination.
Sourceasync fn shutdown(&mut self) -> Result<()>
async fn shutdown(&mut self) -> Result<()>
Initiates or attempts to shut down this writer, returning success when
the I/O connection has completely shut down.
Sourceasync fn write_vectored<T: IoVectoredBuf>(
&mut self,
buf: T,
) -> BufResult<usize, T>
async fn write_vectored<T: IoVectoredBuf>( &mut self, buf: T, ) -> BufResult<usize, T>
Like
write, except that it write bytes from a buffer implements
IoVectoredBuf into the source. Read moreSourceimpl<W> Splittable for WriteOnly<W>
impl<W> Splittable for WriteOnly<W>
Sourcetype ReadHalf = ()
type ReadHalf = ()
The type of the read half, which normally implements
AsyncRead or
AsyncReadAt.Sourcetype WriteHalf = W
type WriteHalf = W
The type of the write half, which normally implements
AsyncWrite or
AsyncWriteAt.Auto Trait Implementations
impl<W> Freeze for WriteOnly<W>where
W: Freeze,
impl<W> RefUnwindSafe for WriteOnly<W>where
W: RefUnwindSafe,
impl<W> Send for WriteOnly<W>where
W: Send,
impl<W> Sync for WriteOnly<W>where
W: Sync,
impl<W> Unpin for WriteOnly<W>where
W: Unpin,
impl<W> UnsafeUnpin for WriteOnly<W>where
W: UnsafeUnpin,
impl<W> UnwindSafe for WriteOnly<W>where
W: UnwindSafe,