pub trait AsyncReadManaged {
type Buffer: IoBuf;
// Required method
async fn read_managed(&mut self, len: usize) -> Result<Option<Self::Buffer>>;
}Expand description
AsyncReadManaged
Async read with buffer pool
Required Associated Types
Required Methods
Sourceasync fn read_managed(&mut self, len: usize) -> Result<Option<Self::Buffer>>
async fn read_managed(&mut self, len: usize) -> Result<Option<Self::Buffer>>
Read some bytes from this source and return a Self::Buffer.
Returning Ok(None) is similar to Ok(0) for normal AsyncRead.
Implementation Note
- If
len== 0, implementation should use buffer’s size aslen - if
len> 0,min(len, buffer_size)will be the max number of bytes to be read.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".