AsyncReadManagedAt

Trait AsyncReadManagedAt 

pub trait AsyncReadManagedAt {
    type Buffer: IoBuf;

    // Required method
    async fn read_managed_at(
        &self,
        len: usize,
        pos: u64,
    ) -> Result<Option<Self::Buffer>>;
}
AsyncReadAtManaged

Async read with buffer pool and position

Required Associated Types

type Buffer: IoBuf

Filled buffer type

Required Methods

async fn read_managed_at( &self, len: usize, pos: u64, ) -> Result<Option<Self::Buffer>>

Read some bytes from this source at position and return a Self::Buffer.

Returning Ok(None) is similar to Ok(0) for normal AsyncReadAt.

Implementation Note
  • If len == 0, implementation should use buffer’s size as len
  • if len > 0, min(len, buffer_size) will be the max number of bytes to be read.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors